/**
 * # redux > market > initialState.js
 *
 * This class is a Immutable object
 * look at : https://facebook.github.io/immutable-js/docs/#/Record
 *  use get(),set(),remove()
 */

/**
 * ## Import
 */
'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});

var _require = require('immutable');

var Record = _require.Record;
var Map = _require.Map;

// Status = oneOf [USER_NOT_ALLOWED,SUCCESS_WITH_ZERO_RESULTS,NETWORK_ERROR,LOADING,SUCCESS]

var InitialState = Record({
  // Collection
  collections: Map(),
  /* collections:
        data for each Query By target name,
          collections :{
            wine: List({...},{...}),
            travel: List()
          }
  */
  collectionsQueryStatus: Map(),
  /* collectionsQueryStatus:
        Status for each Query By target name,
          collectionsQueryStatus :{
            wine: 'SUCCESS_WITH_ZERO_RESULTS',
            travel: 'LOADING'
          }
  */
  collectionsCount: Map(),
  /* collectionsCount:
        count data for each Query By target name,
          collectionsCount :{
            wine: 2,
            travel: 0
          }
  */
  // Document
  documentsByObjectId: Map(),
  /* documentsByObjectId:
        data for document By ObjectId,
        look like-
          documentsByObjectId :{
            A3kfi45: Map({....}),
            TTGH77h: Map({....}),
          }
  */
  documentsByObjectIdQueryStatus: Map(),
  // New Document
  documentsByUniqueId: Map(),
  documentsByUniqueIdQueryStatus: Map(),
  /* documentsByUniqueIdQueryStatus:
        object Status for each Query By UniqueId,
        005f-ce-53-97-24cee4: {
          status: one.of(''LOADING','SUCCESS','ERROR),
            objectId: 'A2343fV' // after finish successfully
        }
        And when created successfully
        look like-
          categoriesDataStatusForEachCategory :{
            wine: 'SUCCESS_WITH_ZERO_RESULTS',
            travel: 'LOADING'
          }
  */
  // Collection
  cloudCodes: Map(),
  /* cloudCodes:
        data for each Query By target name,
          cloudCodes :{
            wine: List({...},{...}),
            travel: List()
          }
  */
  cloudCodesQueryStatus: Map(),
  /* cloudCodesQueryStatus:
        Status for each Query By target name,
          cloudCodesQueryStatus :{
            wine: 'SUCCESS_WITH_ZERO_RESULTS',
            travel: 'LOADING'
          }
  */
  cloudCodesCount: Map()
});

/* cloudCodesCount:
      count data for each Query By target name,
        cloudCodesCount :{
          wine: 2,
          travel: 0
        }
*/
exports['default'] = InitialState;
module.exports = exports['default'];