/**
 * # redux > market > actions.js
 *
 * This file contain all market Actions
 */

// Import all the ActionTypes
'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _types = require('./types');

var _types2 = _interopRequireDefault(_types);

// Get Collection by className
var getCollectionByClassName = function getCollectionByClassName(className, targetName, query, perPage, page, include, filterByMemberId, keys, count) {
  if (perPage === undefined) perPage = 25;
  var memberFieldName = arguments.length <= 9 || arguments[9] === undefined ? 'member' : arguments[9];
  return {
    type: _types2['default'].GET_COLLECTION_BY_CLASS_NAME,
    className: className,
    targetName: targetName,
    query: query,
    perPage: perPage,
    page: page,
    include: include,
    filterByMemberId: filterByMemberId,
    keys: keys,
    count: count,
    memberFieldName: memberFieldName
  };
};
var setCollectionByTargetName = function setCollectionByTargetName(targetName, data) {
  return {
    type: _types2['default'].SET_COLLECTION_BY_TARGET_NAME,
    targetName: targetName,
    data: data
  };
};
var deleteDocumentFromCollectionOnServer = function deleteDocumentFromCollectionOnServer(className, targetName, objectId) {
  return {
    type: _types2['default'].DELETE_DOCUMENT_FROM_COLLECTION_ON_SERVER,
    className: className,
    targetName: targetName,
    objectId: objectId
  };
};
var updateDocumentFromCollectionOnServer = function updateDocumentFromCollectionOnServer(className, targetName, objectId, data) {
  return {
    type: _types2['default'].UPDATE_DOCUMENT_FROM_COLLECTION_ON_SERVER,
    className: className,
    targetName: targetName,
    objectId: objectId,
    data: data
  };
};
var clearAllCollections = function clearAllCollections() {
  return {
    type: _types2['default'].CLEAR_ALL_COLLECTIONS
  };
};
var setRequestStatusByTargetName = function setRequestStatusByTargetName(target, status) {
  return {
    type: _types2['default'].SET_REQUEST_STATUS_BY_TARGET_NAME,
    target: target,
    status: status
  };
};
var setCountByTargetName = function setCountByTargetName(target, count) {
  return {
    type: _types2['default'].SET_COUNT_BY_TARGET_NAME,
    target: target,
    count: count
  };
};
var removeCollectionByTargetNameFromStore = function removeCollectionByTargetNameFromStore(targetName) {
  return {
    type: _types2['default'].REMOVE_COLLECTION_BY_TARGET_NAME_FROM_STORE,
    targetName: targetName
  };
};
// Get Document by className and objectId
var getDocumentByObjectId = function getDocumentByObjectId(className, objectId, include) {
  return {
    type: _types2['default'].GET_DOCUMENT_BY_OBJECT_ID,
    className: className,
    objectId: objectId,
    include: include
  };
};
var setDocumentByObjectId = function setDocumentByObjectId(objectId, data) {
  return {
    type: _types2['default'].SET_DOCUMENT_BY_OBJECT_ID,
    objectId: objectId,
    data: data
  };
};
var clearAllDocuments = function clearAllDocuments() {
  return {
    type: _types2['default'].CLEAR_ALL_DOCUMENTS
  };
};
var setRequestStatusByObjectId = function setRequestStatusByObjectId(objectId, status) {
  return {
    type: _types2['default'].SET_REQUEST_STATUS_BY_OBJECT_ID,
    objectId: objectId,
    status: status
  };
};
var updateLocalDocumentByObjectId = function updateLocalDocumentByObjectId(objectId, key, value) {
  return {
    type: _types2['default'].UPDATE_LOCAL_DOCUMENT_BY_OBJECT_ID,
    objectId: objectId,
    key: key,
    value: value
  };
};
var removeLocalDocumentByObjectId = function removeLocalDocumentByObjectId(objectId) {
  return {
    type: _types2['default'].REMOVE_LOCAL_DOCUMENT_BY_OBJECT_ID,
    objectId: objectId
  };
};
var updateDocumentOnServerByObjectId = function updateDocumentOnServerByObjectId(className, objectId, keys, disabledAutoGetAfterSave, parseDataBeforeSave) {
  return {
    type: _types2['default'].UPDATE_DOCUMENT_ON_SERVER_BY_OBJECT_ID,
    className: className,
    objectId: objectId,
    keys: keys,
    disabledAutoGetAfterSave: disabledAutoGetAfterSave, // set true if you want that getDocumentByObjectId will not run after the update - not recommended
    parseDataBeforeSave: parseDataBeforeSave // pass function that ger object and return object with parse data
  };
};
var deleteDocumentFromServerByObjectId = function deleteDocumentFromServerByObjectId(className, objectId) {
  return {
    type: _types2['default'].DELETE_DOCUMENT_FROM_SERVER_BY_OBJECT_ID,
    className: className,
    objectId: objectId
  };
};
// New documents
var createLocalDocumentByUniqueId = function createLocalDocumentByUniqueId(uniqueId, defaultValues) {
  return {
    type: _types2['default'].CREATE_LOCAL_DOCUMENT_BY_UNIQUE_ID,
    uniqueId: uniqueId,
    defaultValues: defaultValues
  };
};
var updateLocalDocumentByUniqueId = function updateLocalDocumentByUniqueId(uniqueId, key, value) {
  return {
    type: _types2['default'].UPDATE_LOCAL_DOCUMENT_BY_UNIQUE_ID,
    uniqueId: uniqueId,
    key: key,
    value: value
  };
};
var clearLocalDocumentByUniqueId = function clearLocalDocumentByUniqueId(uniqueId) {
  return {
    type: _types2['default'].CLEAR_LOCAL_DOCUMENT_BY_UNIQUE_ID,
    uniqueId: uniqueId
  };
};
var removeLocalDocumentByUniqueId = function removeLocalDocumentByUniqueId(uniqueId) {
  return {
    type: _types2['default'].REMOVE_LOCAL_DOCUMENT_BY_UNIQUE_ID,
    uniqueId: uniqueId
  };
};
var postLocalDocumentByUniqueIdToServer = function postLocalDocumentByUniqueIdToServer(className, uniqueId, parseDataBeforeSave, addMemberPointerToDataOnPost, getDataWithPostQueryStatusSuccessfully) {
  return {
    type: _types2['default'].POST_LOCAL_DOCUMENT_BY_UNIQUE_ID_TO_SERVER,
    className: className,
    uniqueId: uniqueId,
    parseDataBeforeSave: parseDataBeforeSave,
    addMemberPointerToDataOnPost: addMemberPointerToDataOnPost,
    getDataWithPostQueryStatusSuccessfully: getDataWithPostQueryStatusSuccessfully
  };
};
var setRequestStatusByUniqueId = function setRequestStatusByUniqueId(uniqueId, status, data) {
  return {
    type: _types2['default'].SET_REQUEST_STATUS_BY_UNIQUE_ID,
    uniqueId: uniqueId,
    status: status,
    data: data
  };
};
// Get data by clodCodeName
var getDataByCloudCodeName = function getDataByCloudCodeName(functionName, targetName, params, filterByMemberId) {
  var memberFieldName = arguments.length <= 4 || arguments[4] === undefined ? 'member' : arguments[4];
  var digToDataString = arguments.length <= 5 || arguments[5] === undefined ? 'data.result' : arguments[5];
  return {
    type: _types2['default'].GET_DATA_BY_CLOUD_CODE_NAME,
    functionName: functionName,
    targetName: targetName,
    params: params,
    filterByMemberId: filterByMemberId,
    memberFieldName: memberFieldName,
    digToDataString: digToDataString
  };
};
var setCloudCodeByTargetName = function setCloudCodeByTargetName(targetName, data) {
  return {
    type: _types2['default'].SET_CLOUD_CODE_BY_TARGET_NAME,
    targetName: targetName,
    data: data
  };
};
var clearAllCloudCodes = function clearAllCloudCodes() {
  return {
    type: _types2['default'].CLEAR_ALL_CLOUD_CODES
  };
};
var setCloudCodeRequestStatusByTargetName = function setCloudCodeRequestStatusByTargetName(target, status) {
  return {
    type: _types2['default'].SET_CLOUD_CODE_REQUEST_STATUS_BY_TARGET_NAME,
    target: target,
    status: status
  };
};
var removeCloudCodeDataByTargetNameFromStore = function removeCloudCodeDataByTargetNameFromStore(targetName) {
  return {
    type: _types2['default'].REMOVE_CLOUD_CODE_DATA_BY_TARGET_NAME_FROM_STORE,
    targetName: targetName
  };
};
exports.
// Collection
getCollectionByClassName = getCollectionByClassName;
exports.setCollectionByTargetName = setCollectionByTargetName;
exports.deleteDocumentFromCollectionOnServer = deleteDocumentFromCollectionOnServer;
exports.updateDocumentFromCollectionOnServer = updateDocumentFromCollectionOnServer;
exports.clearAllCollections = clearAllCollections;
exports.setRequestStatusByTargetName = setRequestStatusByTargetName;
exports.setCountByTargetName = setCountByTargetName;
exports.removeCollectionByTargetNameFromStore = removeCollectionByTargetNameFromStore;
exports.
// Document
getDocumentByObjectId = getDocumentByObjectId;
exports.setDocumentByObjectId = setDocumentByObjectId;
exports.clearAllDocuments = clearAllDocuments;
exports.removeLocalDocumentByObjectId = removeLocalDocumentByObjectId;
exports.setRequestStatusByObjectId = setRequestStatusByObjectId;
exports.updateLocalDocumentByObjectId = updateLocalDocumentByObjectId;
exports.updateDocumentOnServerByObjectId = updateDocumentOnServerByObjectId;
exports.deleteDocumentFromServerByObjectId = deleteDocumentFromServerByObjectId;
exports.
// New Document
createLocalDocumentByUniqueId = createLocalDocumentByUniqueId;
exports.updateLocalDocumentByUniqueId = updateLocalDocumentByUniqueId;
exports.clearLocalDocumentByUniqueId = clearLocalDocumentByUniqueId;
exports.removeLocalDocumentByUniqueId = removeLocalDocumentByUniqueId;
exports.setRequestStatusByUniqueId = setRequestStatusByUniqueId;
exports.postLocalDocumentByUniqueIdToServer = postLocalDocumentByUniqueIdToServer;
exports.
// Cloud Codes
getDataByCloudCodeName = getDataByCloudCodeName;
exports.setCloudCodeByTargetName = setCloudCodeByTargetName;
exports.clearAllCloudCodes = clearAllCloudCodes;
exports.setCloudCodeRequestStatusByTargetName = setCloudCodeRequestStatusByTargetName;
exports.removeCloudCodeDataByTargetNameFromStore = removeCloudCodeDataByTargetNameFromStore;