/**
 * # redux > market > reducer.js
 *
 * This file contain all market Reducers
 */

// Import all the types
'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});
exports['default'] = parseReducer;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _types = require('./types');

var _types2 = _interopRequireDefault(_types);

// Import market InitialState

var _InitialState = require('./InitialState');

var _InitialState2 = _interopRequireDefault(_InitialState);

var initialState = new _InitialState2['default']();

var _require = require('immutable');

var Map = _require.Map;
var List = _require.List;

// Import  charm-helpers tools and lodash
// import { digAndReturnArrayOnly } from '../../tools/charm-helpers'
// import _ from 'lodash'
/**
 * ## TEMPLATEReducer function
 * @param {Object} state - initialState
 * @param {Object} action - type and payload
 */
// export const getDataFromState = (state, target, reducer = 'market') => {
//   if (!target) { return state[reducer] }
//   return state[reducer][target]
// }
var getDataFromState = function getDataFromState(state, target) {
  if (!target) {
    return state.market;
  }
  return state.market[target];
};
exports.getDataFromState = getDataFromState;

function parseReducer(state, action) {
  if (state === undefined) state = initialState;

  if (!(state instanceof _InitialState2['default'])) return initialState.merge(state);
  switch (action.type) {
    // Collection
    case _types2['default'].CLEAR_ALL_COLLECTIONS:
      {
        return state.set('collections', Map()).set('collectionsQueryStatus', Map()).set('collectionsCount', Map());
      }
    case _types2['default'].SET_COLLECTION_BY_TARGET_NAME:
      {
        var targetName = action.targetName;
        var data = action.data;
        var nextState = state.setIn(['collections', targetName], List(data));
        return nextState;
      }
    case _types2['default'].SET_REQUEST_STATUS_BY_TARGET_NAME:
      {
        return state.setIn(['collectionsQueryStatus', action.targetName], action.status);
      }
    case _types2['default'].SET_COLLECTION_PARAMETERS:
      {
        var targetName = action.targetName;
        var nextState = state.setIn(['collectionsQueryStatus', targetName], action.status);
        nextState = nextState.setIn(['collections', targetName], List(action.data));
        return nextState.setIn(['collectionsCount', targetName], action.count);
      }
    case _types2['default'].SET_COUNT_BY_TARGET_NAME:
      {
        return state.setIn(['collectionsCount', action.targetName], action.count);
      }
    case _types2['default'].REMOVE_COLLECTION_BY_TARGET_NAME_FROM_STORE:
      {
        var nextState = state.setIn(['collectionsQueryStatus', action.targetName], null);
        nextState = nextState.setIn(['collections', action.targetName], null);
        return nextState;
      }
    // Document
    case _types2['default'].CLEAR_ALL_DOCUMENTS:
      {
        return state.set('documentsByObjectId', Map()).set('documentsByObjectIdQueryStatus', Map());
      }
    case _types2['default'].SET_DOCUMENT_BY_OBJECT_ID:
      {
        var objectId = action.objectId;
        var data = action.data;
        if (!data) return state.setIn(['documentsByObjectId', objectId], null);
        var nextState = state.setIn(['documentsByObjectId', objectId], Map(data));
        return nextState;
      }
    case _types2['default'].REMOVE_LOCAL_DOCUMENT_BY_OBJECT_ID:
      {
        var nextState = state.setIn(['documentsByObjectIdQueryStatus', action.objectId], null);
        nextState = nextState.setIn(['documentsByObjectId', action.objectId], null);
        return nextState;
      }
    case _types2['default'].UPDATE_LOCAL_DOCUMENT_BY_OBJECT_ID:
      {
        var objectId = action.objectId;
        var key = action.key;
        var value = action.value;

        var nextState = state.setIn(['documentsByObjectId', objectId, key], value);
        return nextState;
      }
    case _types2['default'].SET_REQUEST_STATUS_BY_OBJECT_ID:
      {
        return state.setIn(['documentsByObjectIdQueryStatus', action.objectId], action.status);
      }
    // New Document
    case _types2['default'].CREATE_LOCAL_DOCUMENT_BY_UNIQUE_ID:
      {
        return state.setIn(['documentsByUniqueId', action.uniqueId], Map(action.defaultValues)).setIn(['documentsByUniqueIdQueryStatus', action.uniqueId], Map());
      }
    case _types2['default'].CLEAR_LOCAL_DOCUMENT_BY_UNIQUE_ID:
      {
        return state.setIn(['documentsByUniqueId', action.uniqueId], Map()).setIn(['documentsByUniqueIdQueryStatus', action.uniqueId], Map()); // this Map contain status&objectId after create on server
      }
    case _types2['default'].REMOVE_LOCAL_DOCUMENT_BY_UNIQUE_ID:
      {
        // let nextState = state.set().documentsByUniqueId.filter((val, key) => key !== action.uniqueId)
        // nextState = nextState.documentsByUniqueIdQueryStatus.filter((val, key) => key !== action.uniqueId)
        // return nextState
        return state.setIn(['documentsByUniqueId', action.uniqueId], null).setIn(['documentsByUniqueIdQueryStatus', action.uniqueId], null); // this Map contain status&objectId after create on server
      }
    case _types2['default'].UPDATE_LOCAL_DOCUMENT_BY_UNIQUE_ID:
      {
        var uniqueId = action.uniqueId;
        var key = action.key;
        var value = action.value;

        var nextState = state.setIn(['documentsByUniqueId', uniqueId, key], value);
        return nextState;
      }
    case _types2['default'].SET_REQUEST_STATUS_BY_UNIQUE_ID:
      {
        var uniqueId = action.uniqueId;
        var _status = action.status;
        var objectId = action.objectId;
        var data = action.data;

        return state.setIn(['documentsByUniqueIdQueryStatus', uniqueId], Map({
          status: _status,
          objectId: objectId,
          data: data
        }));
      }
    // Cloud code
    case _types2['default'].CLEAR_ALL_CLOUD_CODES:
      {
        return state.set('cloudCodes', Map()).set('cloudCodesQueryStatus', Map());
      }
    case _types2['default'].SET_CLOUD_CODES_BY_TARGET_NAME:
      {
        var targetName = action.targetName;
        var data = action.data;
        var nextState = state.setIn(['cloudCodes', targetName], List(data));
        return nextState;
      }
    case _types2['default'].SET_CLOUD_CODES_REQUEST_STATUS_BY_TARGET_NAME:
      {
        return state.setIn(['cloudCodesQueryStatus', action.targetName], action.status);
      }
    case _types2['default'].SET_CLOUD_CODE_PARAMETERS:
      {
        var targetName = action.targetName;
        var nextState = state.setIn(['cloudCodesQueryStatus', targetName], action.status);
        return nextState.setIn(['cloudCodes', targetName], List(action.data));
      }
    case _types2['default'].REMOVE_CLOUD_CODE_DATA_BY_TARGET_NAME_FROM_STORE:
      {
        var nextState = state.setIn(['cloudCodesQueryStatus', action.targetName], null);
        nextState = nextState.setIn(['cloudCodes', action.targetName], null);
        return nextState;
      }
  }
  return state;
}